@@ -21,6 +21,7 @@
 
 #include "config.h"
 #include <gnome.h>
+#include <glib/gi18n.h>
 #include <string.h>
 #include <dirent.h>
 #include <games-clock.h>
@@ -33,13 +34,28 @@
 #include "properties.h"
 #include "gataxx.h"
 
+#define GCONF_PREFIX "/apps/gataxx/"
+
+#define GCONF_BLACKLEVEL GCONF_PREFIX "blacklevel"
+#define GCONF_WHITELEVEL GCONF_PREFIX "whitelevel"
+#define GCONF_QUICKMOVES GCONF_PREFIX "quickmoves"
+#define GCONF_THEME GCONF_PREFIX "theme"
+#define GCONF_ANIMATE GCONF_PREFIX "animate"
+
+typedef struct {
+	gint black_level;
+	gint white_level;
+	gboolean animate;
+	gboolean quick_moves;
+        gchar * theme;
+} PropertiesData;
+
 PropertiesData _props;
 PropertiesData * props=&_props;
 
 static GtkWidget *propbox = NULL;
 static GtkWindow * mainwindow = NULL;
 static GtkTooltips *tooltips = NULL;
-static GamesFileList * theme_file_list = NULL;
 
 /* makes sure input lies between low and high */
 static gint clamp_int (gint input, gint low, gint high)
@@ -71,14 +87,6 @@ int props_get_black_level() {
 	return props->black_level;
 }
 
-gboolean props_get_flip_final() {
-	return props->flip_final;
-}
-
-gboolean props_get_show_grid() {
-	return props->show_grid;
-}
-
 gboolean props_get_animate() {
 	return props->animate;
 }
@@ -87,16 +95,16 @@ gboolean props_get_quick_moves() {
 	return props->quick_moves;
 }
 
-gchar * props_get_tile_set() {
-	return props->tile_set;
+gchar * props_get_theme() {
+	return props->theme;
 }
 
 /* functions to get things from gconf */
-static int props_get_int(const char * setting, int def, int low, int high) {
+static int props_get_int(const gchar * key, int def, int low, int high) {
 	int result;
 	GError * error=NULL;
 
-	result=gconf_client_get_int(get_gconf_client(), get_gconf_uri(setting), &error);
+	result=gconf_client_get_int(get_gconf_client(), key, &error);
 	if (error!=NULL) {
 		g_error_free(error);
 		return def;
@@ -105,11 +113,11 @@ static int props_get_int(const char * setting, int def, int low, int high) {
 	return result;
 }
 
-static gboolean props_get_bool(gchar * key, gboolean def) {
+static gboolean props_get_bool(const gchar * key, gboolean def) {
 	GError * error=NULL;
 	gboolean result;
 
-	result=gconf_client_get_bool(get_gconf_client(), get_gconf_uri(key), &error);
+	result=gconf_client_get_bool(get_gconf_client(), key, &error);
 	if (error!=NULL) {
 		g_error_free(error);
 		return def;
@@ -121,12 +129,12 @@ static gboolean props_get_bool(gchar * key, gboolean def) {
 /* FIXME: watch this: */
 /* Returns gchar* you should free with g_free(). Returns NULL on not-found
  * or other error. */
-static gchar * props_get_string(gchar *key)
+static gchar * props_get_string(const gchar *key)
 {
 	GError *error = NULL;
 	gchar *retval;
 
-	retval = gconf_client_get_string (get_gconf_client(), get_gconf_uri(key), &error);
+	retval = gconf_client_get_string (get_gconf_client(), key, &error);
 	if (error != NULL) {
 		g_error_free (error);
 		return NULL;
@@ -137,36 +145,29 @@ static gchar * props_get_string(gchar *key)
 
 void load_properties (void)
 {
-	props->black_level=props_get_int("blacklevel", 0, 0, 3);
-	props->white_level=props_get_int("whitelevel", 0, 0, 3);
+	props->black_level=props_get_int(GCONF_BLACKLEVEL, 0, 0, 3);
+	props->white_level=props_get_int(GCONF_WHITELEVEL, 0, 0, 3);
 
-	props->tile_set=props_get_string("tileset");
-	if (props->tile_set == NULL) props->tile_set = g_strdup("classic.png");
-
-	props->animate=props_get_bool("animate", TRUE);
-	props->show_grid=props_get_bool("showgrid", TRUE);
-	props->quick_moves=props_get_bool("quickmoves", FALSE);
-	props->flip_final=props_get_bool ("flipfinal", TRUE);
+	props->theme=props_get_string(GCONF_THEME);
+	if (props->theme == NULL) props->theme = g_strdup("Plain");
 
+	props->animate=props_get_bool(GCONF_ANIMATE, TRUE);
+	props->quick_moves=props_get_bool(GCONF_QUICKMOVES, FALSE);
 }
 
 static void
 save_properties (void)
 {
-	gconf_client_set_int (get_gconf_client(), get_gconf_uri("blacklevel"),
+	gconf_client_set_int (get_gconf_client(), GCONF_BLACKLEVEL,
 	                      props->black_level, NULL);
-	gconf_client_set_int (get_gconf_client(), get_gconf_uri("whitelevel"),
+	gconf_client_set_int (get_gconf_client(), GCONF_WHITELEVEL,
 	                      props->white_level, NULL);
-	gconf_client_set_bool (get_gconf_client(), get_gconf_uri("quickmoves"),
+	gconf_client_set_bool (get_gconf_client(), GCONF_QUICKMOVES,
 	                       props->quick_moves, NULL);
-	gconf_client_set_string (get_gconf_client(), get_gconf_uri("tileset"),
-	                         props->tile_set, NULL);
-	gconf_client_set_bool (get_gconf_client(), get_gconf_uri("animate"),
+	gconf_client_set_string (get_gconf_client(), GCONF_THEME,
+	                         props->theme, NULL);
+	gconf_client_set_bool (get_gconf_client(), GCONF_ANIMATE,
 	                      props->animate, NULL);
-	gconf_client_set_bool (get_gconf_client(), get_gconf_uri("showgrid"),
-	                      props->show_grid, NULL);
-	gconf_client_set_bool (get_gconf_client(), get_gconf_uri("flipfinal"),
-	                       props->flip_final, NULL);
 }
 
 /* callbacks for the various check and radiobuttons */
@@ -194,18 +195,18 @@ set_variable_cb(GtkWidget * widget, gpointer data) {
 	apply_changes();
 }
 
-/* callback for the tileset menu */ 
 static void
 set_selection (GtkWidget *widget, gpointer data)
 {
-        gchar *filename;
+	int n;
 
-	if (props->tile_set)
-		g_free (props->tile_set);
+	if (props->theme)
+		g_free (props->theme);
 
-	filename = games_file_list_get_nth (theme_file_list, 
-					    gtk_combo_box_get_active (GTK_COMBO_BOX (widget)));
-	props->tile_set = g_strdup (filename);
+	/* We can't use _get_active_text since the text may be
+	 * translated. */
+	n = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
+	props->theme = g_strdup (gtk_gridboard_themes[n].name);
 
 	save_properties ();
 	apply_changes();
@@ -213,31 +214,31 @@ set_selection (GtkWidget *widget, gpointer data)
 
 /* fills the pixmap options menu */
 static GtkWidget *
-fill_tileset_menu (void)
+fill_theme_menu (void)
 {
-	/* Note that we are sharing pixmaps with iagno here. */
-	gchar *dname = gnome_program_locate_file (NULL,
-						  GNOME_FILE_DOMAIN_APP_PIXMAP,
-						  ("iagno"), FALSE, NULL);
+        GtkWidget *combo_box;
+	GtkGridBoardTheme *t;
+	int n;
 
+	combo_box = gtk_combo_box_new_text ();
 
-        if (theme_file_list)
-                g_object_unref (theme_file_list);
- 
-        theme_file_list = games_file_list_new_images (dname, NULL);
-        g_free (dname);
-        games_file_list_transform_basename (theme_file_list);
- 
-        return games_file_list_create_widget (theme_file_list, props->tile_set,
-                                              GAMES_FILE_LIST_REMOVE_EXTENSION
-|
-                                              GAMES_FILE_LIST_REPLACE_UNDERSCORES);
+	t = gtk_gridboard_themes;
+	n = 0;
+	while (t->name != NULL) {
+	  gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _(t->name));
+	  if (g_utf8_collate (t->name, props->theme) == 0)
+	    gtk_combo_box_set_active (GTK_COMBO_BOX (combo_box), n);
+	  n++;
+	  t++;
+	}
+
+	return combo_box;
 }
 
 /* makes a perty radio button for a particular computer level */
 static GtkWidget * add_level(GtkWidget * container, 
 		GtkWidget * prev,
-		gchar * caption,
+		const gchar * caption,
 		gint level,
 		gint piece) {
 	GtkWidget * button;
@@ -267,8 +268,6 @@ static gboolean quit_properties_dialog(GtkWidget * widget, gpointer data) {
 	apply_changes();
 	g_object_unref (tooltips);
 	tooltips = NULL;
-	g_object_unref (theme_file_list);
-	theme_file_list = NULL;
 	gtk_widget_destroy(propbox);
 	propbox = NULL;
 	return FALSE;
@@ -302,6 +301,10 @@ void show_properties_dialog (void) {
 					       GTK_RESPONSE_CLOSE,
 					       NULL);
 	
+	gtk_window_set_resizable (GTK_WINDOW (propbox), FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (propbox), 5);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (propbox)->vbox), 2);
+	
 	g_signal_connect (G_OBJECT (propbox), "response",
 			  G_CALLBACK (quit_properties_dialog), &propbox);
 
@@ -316,24 +319,24 @@ void show_properties_dialog (void) {
 	/* create notebook (tabs) */
 	notebook = gtk_notebook_new ();
 	gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_TOP);
+	gtk_container_set_border_width (GTK_CONTAINER (notebook), 5);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (propbox)->vbox), notebook, TRUE, TRUE, 0);
 	
 	/* Players tab */
 	
-	/* FIXME mnemonic doesn't seem to work */
-	label = gtk_label_new_with_mnemonic (_("_Players"));
+	label = gtk_label_new (_("Players"));
 
-	vbox = gtk_vbox_new (FALSE, 0);
+	vbox = gtk_vbox_new (FALSE, 18);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
 
 	table = gtk_table_new (1, 2, FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (table), 6);
+	gtk_table_set_col_spacings (GTK_TABLE (table), 18);
         gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
 
 	vbox2 = gtk_vbox_new (FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox2), 12);
         gtk_box_pack_start (GTK_BOX (vbox), vbox2, FALSE, FALSE, 0);
-	button = gtk_check_button_new_with_label (_("Quick Moves"));
+	button = gtk_check_button_new_with_mnemonic (_("_Quick moves"));
 	gtk_tooltips_set_tip(tooltips, button, _("Shortens the time a computer waits before doing a move"), NULL);	
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				     props->quick_moves);
@@ -346,84 +349,66 @@ void show_properties_dialog (void) {
 	frame = games_frame_new (_("Dark"));
 	
 	vbox2 = gtk_vbox_new (FALSE, 6);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox2), 6);
 	
-	button=add_level(vbox2, NULL, _("Human"), 	0, BLACK);
-	button=add_level(vbox2, button, _("Very Easy"),	1, BLACK);
-	button=add_level(vbox2, button, _("Easy"), 	2, BLACK);
-	button=add_level(vbox2, button, _("Medium"), 	3, BLACK);
-	button=add_level(vbox2, button, _("Hard"), 	4, BLACK);
-	button=add_level(vbox2, button, _("Very Hard"), 5, BLACK);
+	button=add_level(vbox2, NULL,    _("Human"), 	        0, BLACK);
+	button=add_level(vbox2, button,  _("Very easy"),	1, BLACK);
+	button=add_level(vbox2, button, Q_("gataxx|Easy"), 	2, BLACK);
+	button=add_level(vbox2, button, Q_("gataxx|Medium"), 	3, BLACK);
+	button=add_level(vbox2, button,  _("Hard"), 	        4, BLACK);
+	button=add_level(vbox2, button,  _("Very hard"),        5, BLACK);
 
 	gtk_container_add (GTK_CONTAINER (frame), vbox2);
 	
 	gtk_table_attach (GTK_TABLE (table), frame, 1, 2, 0, 1,
 			  GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
-			  6, 6);
+			  0, 0);
 	
 	/* Light level select */
 	frame = games_frame_new (_("Light"));
 
 	vbox2 = gtk_vbox_new (FALSE, 6);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox2), 6);
 	
 	button=add_level(vbox2, NULL, _("Human"), 0, WHITE);
-	button=add_level(vbox2, button, _("Very Easy"), 1, WHITE);
+	button=add_level(vbox2, button, _("Very easy"), 1, WHITE);
 	button=add_level(vbox2, button, _("Easy"), 	2, WHITE);
 	button=add_level(vbox2, button, _("Medium"), 	3, WHITE);
 	button=add_level(vbox2, button, _("Hard"), 	4, WHITE);
-	button=add_level(vbox2, button, _("Very Hard"), 5, WHITE);
+	button=add_level(vbox2, button, _("Very hard"), 5, WHITE);
 	
 	gtk_container_add (GTK_CONTAINER (frame), (vbox2));
 
 	gtk_table_attach (GTK_TABLE (table), frame, 0, 1, 0, 1,
 			  GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
-			  6, 6);
+			  0, 0);
 
 	/* Appearance tab */
-	label = gtk_label_new_with_mnemonic (_("_Appearance"));
+	label = gtk_label_new (_("Appearance"));
 	vbox = gtk_vbox_new (FALSE, 6);
 
         frame = games_frame_new (_("Appearance"));
 	gtk_container_add (GTK_CONTAINER (frame), vbox);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), frame, label);
+	gtk_container_set_border_width (GTK_CONTAINER (frame), 12);
 
 	/* animation button */
-	button=gtk_check_button_new_with_label(_("Animation"));
+	button=gtk_check_button_new_with_mnemonic(_("_Animation"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), props->animate);
 	g_signal_connect(G_OBJECT(button), "toggled",
 			G_CALLBACK(set_variable_cb), &(props->animate));
 	gtk_tooltips_set_tip(tooltips, button, _("Flip the pieces with some visual effects"), NULL);	
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
-	/* flip tiles button */
-	button=gtk_check_button_new_with_label(_("Flip final results"));
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), props->flip_final);
-	g_signal_connect(G_OBJECT(button), "toggled",
-			G_CALLBACK(set_variable_cb), &(props->flip_final));
-	gtk_tooltips_set_tip(tooltips, button, _("Put all the white pieces at the bottom and all the black pieces on the top of the board when a game is over"), NULL);	
-	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-
-	/* show grid button */
-	button=gtk_check_button_new_with_label(_("Show grid"));
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), props->show_grid);
-	g_signal_connect(G_OBJECT(button), "toggled",
-			G_CALLBACK(set_variable_cb), &(props->show_grid));
-	gtk_tooltips_set_tip(tooltips, button, _("Whether the grid should be shown"), NULL);	
-	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-
-	/* FIXME stagger flips button? */
-
-	/*  tileset select */
-	hbox=gtk_hbox_new(FALSE, GNOME_PAD);
-	label=gtk_label_new(_("Tile set:"));
+	/*  theme select */
+	hbox=gtk_hbox_new(FALSE, 12);
+	label=gtk_label_new_with_mnemonic(_("_Tile set:"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	menu = fill_tileset_menu ();
+	menu = fill_theme_menu ();
 	g_signal_connect (G_OBJECT (menu), "changed",
 			  G_CALLBACK (set_selection), NULL);
 	gtk_tooltips_set_tip(tooltips, menu, _("The appearance of the pieces"), NULL);	
 	gtk_box_pack_start(GTK_BOX(hbox), menu, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+	gtk_label_set_mnemonic_widget(GTK_LABEL (label), menu);
 
 	/* end of appearance tab */
 	gtk_widget_show_all (propbox);
@@ -434,8 +419,8 @@ void show_properties_dialog (void) {
 void
 reload_properties (void)
 {
-	g_free (props->tile_set);
-	props->tile_set = NULL;
+	g_free (props->theme);
+	props->theme = NULL;
 	load_properties ();
 	apply_changes ();
 }
